@@ -1,5 +1,5 @@
 ;;;; psgml-dtd.el --- DTD parser for SGML-editing mode with parsing support
-;; $Id: psgml-dtd.el,v 2.27 2001/04/02 22:04:44 lenst Exp $
+;; $Id: psgml-dtd.el,v 2.28 2002/02/08 14:10:25 lenst Exp $
 
 ;; Copyright (C) 1994 Lennart Staflin
 
@@ -995,15 +995,15 @@ FORMS should produce the binary coding of element in VAR."
 (defun sgml-write-dtd (dtd file)
   "Save the parsed dtd on FILE.
 Construct the binary coded DTD (bdtd) in the current buffer."
-  (when (fboundp 'set-buffer-multibyte)
-    (setq buffer-file-coding-system 'no-conversion)
-    (set-buffer-multibyte nil))
+  (sgml-set-buffer-multibyte nil)
   (insert
-   ";;; This file was created by psgml on " (current-time-string) "\n"
+   ";;; This file was created by psgml on " (current-time-string)
+   " -*-coding:binary-*-\n"
    "(sgml-saved-dtd-version 7)\n")
-  (sgml-code-dtd dtd)
-  (set 'file-type 1)
-  (write-region (point-min) (point-max) file))
+  (let ((print-escape-multibyte t))
+    (sgml-code-dtd dtd))
+  (let ((coding-system-for-write 'no-conversion))
+    (write-region (point-min) (point-max) file)))
 
 
 ;;; psgml-dtd.el ends here
